@@ -30,7 +30,7 @@ def markdown_filter(value):
 
 def filter_template_dir(filename):
     _name = os.path.basename(filename)
-    if _name.startswith(".") or ".svn" in _name:
+    if _name.startswith(".") or ".svn" in filename:
         return False;
     return True;
 
